==> vue-media-0.1.1.tgz: package/README.md <==
# vue-media

[![NPM version](https://img.shields.io/npm/v/vue-media.svg?style=flat)](https://npmjs.com/package/vue-media) [![NPM downloads](https://img.shields.io/npm/dm/vue-media.svg?style=flat)](https://npmjs.com/package/vue-media) [![Build Status](https://img.shields.io/circleci/project/egoist/vue-media/master.svg?style=flat)](https://circleci.com/gh/egoist/vue-media) [![donate](https://img.shields.io/badge/$-donate-ff69b4.svg?maxAge=2592000&style=flat)](https://github.com/egoist/donate)

Like [react-media](https://github.com/ReactTraining/react-media) but for Vue.js, and this library is pretty small, it's 969 bytes after minified without gzip.

## Install

```bash
yarn add vue-media
```

CDN: https://unpkg.com/vue-media/dist

## Usage

```vue
<template>
  <div id="app">
    <media :query="{minWidth: 500}">bigger than 500px</media>
    <media :query="{maxWidth: 500}">smaller than 500px</media>
  </div>
</template>

<script>
  import Media from 'vue-media'
  // You can access `window.VueMedia` if using CDN.
  export default {
    components: {
      Media
    }
  }
</script>
```

The value of `query` can also be a [media query string](https://developer.mozilla.org/en-US/docs/Web/CSS/Media_Queries/Using_media_queries) like `(max-width: 500px)`, for more info pleasae see [json2mq](https://github.com/akiran/json2mq/blob/master/README.md#usage) doc.

## Contributing

1. Fork it!
2. Create your feature branch: `git checkout -b my-new-feature`
3. Commit your changes: `git commit -am 'Add some feature'`
4. Push to the branch: `git push origin my-new-feature`
5. Submit a pull request :D


## Author

**vue-media** © [egoist](https://github.com/egoist), Released under the [MIT](./LICENSE) License.<br>
Authored and maintained by egoist with help from contributors ([list](https://github.com/egoist/vue-media/contributors)).

> [egoistian.com](https://egoistian.com) · GitHub [@egoist](https://github.com/egoist) · Twitter [@rem_rin_rin](https://twitter.com/rem_rin_rin)

==> vue-media-1.0.0.tgz: package/README.md <==
# vue-media

[![NPM version](https://img.shields.io/npm/v/vue-media.svg?style=flat)](https://npmjs.com/package/vue-media) [![NPM downloads](https://img.shields.io/npm/dm/vue-media.svg?style=flat)](https://npmjs.com/package/vue-media) [![Build Status](https://img.shields.io/circleci/project/egoist/vue-media/master.svg?style=flat)](https://circleci.com/gh/egoist/vue-media) [![donate](https://img.shields.io/badge/$-donate-ff69b4.svg?maxAge=2592000&style=flat)](https://github.com/egoist/donate)

Like [react-media](https://github.com/ReactTraining/react-media) but for Vue.js, and this library is pretty small, it's 969 bytes after minified without gzip.

## Install

```bash
yarn add vue-media
```

CDN: https://unpkg.com/vue-media/dist

## Usage

```vue
<template>
  <div id="app">
    <media :query="{minWidth: 500}">bigger than 500px</media>
    <media :query="{maxWidth: 500}">smaller than 500px</media>
  </div>
</template>

<script>
  import Media from 'vue-media'
  // You can access `window.VueMedia` if using CDN.
  export default {
    components: {
      Media
    }
  }
</script>
```

The value of `query` can also be a [media query string](https://developer.mozilla.org/en-US/docs/Web/CSS/Media_Queries/Using_media_queries) like `(max-width: 500px)`, for more info please see [json2mq](https://github.com/akiran/json2mq/blob/master/README.md#usage) doc.

This component will only return the **first one of child components**.

```vue
<template>
  <media :query="{maxWidth: 600}">
    <h2>hello world</h2>
    <my-other-component></my-other-component> <!-- this will not be use! -->
  </media>
</template>
```

## Browser support

If you want to support legacy browsers (ie <= 10), please include a `window.matchMedia` [polyfill](https://github.com/paulirish/matchMedia.js/).

## Contributing

1. Fork it!
2. Create your feature branch: `git checkout -b my-new-feature`
3. Commit your changes: `git commit -am 'Add some feature'`
4. Push to the branch: `git push origin my-new-feature`
5. Submit a pull request :D


## Author

**vue-media** © [egoist](https://github.com/egoist), Released under the [MIT](./LICENSE) License.<br>
Authored and maintained by egoist with help from contributors ([list](https://github.com/egoist/vue-media/contributors)).

> [egoistian.com](https://egoistian.com) · GitHub [@egoist](https://github.com/egoist) · Twitter [@rem_rin_rin](https://twitter.com/rem_rin_rin)
